@@ -48,7 +48,7 @@ class IDispatcher:
                     loguru.logger.debug(f"Sent {msg} to {ch.worker_name}")
                 await ch.consume_pipe.write(msg)
 
-    def preform(self) -> List[Future[Any]]:
+    def perform(self) -> List[Future[Any]]:
         tasks = []
         for channel in self.channels.values():
             tasks.append(asyncio.ensure_future(
